namespace Pr19;

class Program
{
    static void Main(string[] args)
    {
        Libreria libreria = new Libreria();
        
        CaricaLibreria(libreria);
        
        Console.WriteLine("Prezzo ISBN 2: " + libreria.PrezzoVendita("0998990922"));

        libreria.OrdinaPerAutoreTitolo();
        Console.WriteLine("Libreria ordinata per Autore e Titolo");
        Console.WriteLine(libreria.StampaLibreria());

        libreria.OrdinaPerGenere();
        Console.WriteLine("Romanzi ordinati per Genere");
        Console.WriteLine(libreria.StampaLibreria());

        Console.WriteLine("Numero libri per tipo");
        Console.WriteLine(libreria.StampaNumeroPerTipo());

        libreria.EliminaLibro("3");
        Console.WriteLine("Dopo eliminazione ISBN 3");
        Console.WriteLine(libreria.StampaLibreria());
    }

    static void CaricaLibreria(Libreria libreria)
    {
        libreria.AggiungiRomanzo("0998990922", "The Asylum For Wayward Victorian Girls", "Emilie Autumn", "Autobiografia", 15.00);
        libreria.AggiungiRomanzo("0151660344", "1984", "George Orwell", "Distopico", 15.00);
        libreria.AggiungiRomanzo("1290457836", "Silo", "Hugh Howey", "Fantascienza", 20.00);
        libreria.AggiungiManuale("3984571026", "Picchiare Di Biase", "Matteo", "Informatica", 500, 35.00);
        libreria.AggiungiManuale("2149057830", "Ho Sonno", "Teresa", "Fisica", 420, 32.00);
        libreria.AggiungiLibroDiTesto("5609183427", "Matematica Blu, Gialla, Rossa e altri colori", "Bergamini", "Matematica", "si", "Volume 1", 28.00);
        libreria.AggiungiLibroDiTesto("9823047619", "La Defenestrazione del 2026", "Il mio vicino di casa", "Storia", "no", "Volume Unico", 80.00);
    }
}